import { useContext, useMemo } from "react";
import { GitRefLink } from "../common/Git/GitRefLink";
import { apiContext } from "../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";
import { Skeleton } from "@mui/material";

export const JobGitRefLink = ({
  gitReference,
  gitProjectId,
  disableExternalLinkIcon = false
}) => {
  const client = useContext(apiContext);
  const projectParams = useMemo(
    () => ({
      project_id: gitProjectId
    }),
    [gitProjectId]
  );

  const { value: project } = useAPIMethod({
    fcn: client.apis.Git.gitProjectDetails,
    params: projectParams
  });

  const shortRefParams = useMemo(
    () => ({
      project_id: gitProjectId,
      reference: gitReference
    }),
    [gitProjectId, gitReference]
  );
  const { value: commits } = useAPIMethod({
    fcn: client.apis.Git.listTagsAndCommitIds,
    params: shortRefParams
  });

  if (!project || !commits) {
    return <Skeleton width={80} />;
  }

  const firstCommit = commits?.at(0);
  const gitRef = firstCommit?.shortReference ?? gitReference;
  const displayReference =
    firstCommit?.type === "TAG"
      ? firstCommit?.reference
      : firstCommit?.short_reference;
  const shortGitHashLength = 8;

  return (
    <>
      {displayReference ? (
        <GitRefLink
          url={project?.projectUrl}
          revision={gitRef}
          displayReference={displayReference}
          label={`External Git Link, project ${project.name}, revision ${gitRef}`}
          disableExternalLinkIcon={disableExternalLinkIcon}
        />
      ) : (
        <span>{gitRef.slice(0, shortGitHashLength)}</span>
      )}
    </>
  );
};
